@@ -22,6 +22,8 @@
 
 /* A list of file formats we will recognize */
 $FORMATS = array("mp3", "oga", "ogg", "wav", "flac");
+$JPLAYER_LIST = "";
+$JPLAYER_OGG = "false";
 
 if (file_exists("/etc/musica/config.php")) {
 	include("/etc/musica/config.php");
@@ -30,7 +32,7 @@ if (file_exists("/etc/musica/config.php")) {
 function sanity_check($string) {
 	$string = urldecode($string);
 	$string = stripslashes($string);
-	if (preg_match("/\.\./", $string)) {
+	if (preg_match("/\.\.\//", $string)) {
 		exit;
 	}
 	if (preg_match("/\//", $string)) {
@@ -73,6 +75,7 @@ $blank = sanity_check($_REQUEST["blank"]);
 $artist = sanity_check($_REQUEST["artist"]);
 $album = sanity_check($_REQUEST["album"]);
 $song = sanity_check($_REQUEST["song"]);
+$about = sanity_check($_REQUEST["about"]);
 $misc = sanity_check($_REQUEST["misc"]);
 $playlist = sanity_check($_REQUEST["playlist"]);
 $download_album = sanity_check($_REQUEST["download_album"]);
@@ -81,7 +84,11 @@ $rating = sanity_check($_REQUEST["rating"]);
 $user = sanity_check($_SERVER["PHP_AUTH_USER"]);
 $pw = sanity_check($_SERVER["PHP_AUTH_PW"]);
 
-$PREAMBLE = "http://" . $_SERVER["HTTP_HOST"] . dirname($_SERVER["SCRIPT_NAME"]) . "/music/";
+$PROTO = "http";
+if ($_SERVER["HTTPS"] == "on") {
+	$PROTO .= "s";
+}
+$PREAMBLE = "$PROTO://" . $_SERVER["HTTP_HOST"] . dirname($_SERVER["SCRIPT_NAME"]) . "/music/";
 
 if (!$playlist && ! $download_album) {
 ?>
@@ -89,18 +96,20 @@ if (!$playlist && ! $download_album) {
 <html>
 <head>
 <title>Musica</title>
+<link href="skin/jplayer.blue.monday.css" rel="stylesheet" type="text/css" />
 <style>
 <!--
 a {text-decoration: none; color: blue}
 a:hover {text-decoration: underline; }
-a:visted {text-decoration: none;}
+a:visited {text-decoration: none;}
 a.head {text-decoration: none; color: white}
 a.head:hover {text-decoration: underline; }
-a.head:visted {text-decoration: none;}
+a.head:visited {text-decoration: none;}
 img { border: none; }
 body {font-size: 13px; font-family: verdana,arial,helvetica,sans-serif; font-weight: 400; color: #000000;}
 -->
 </style>
+<link rel="shortcut icon" href="/musica/favicon.ico" type="image/x-icon">
 </head>
 
 <?
@@ -351,23 +360,24 @@ function print_album($artist, $album) {
 }
 
 function print_song($artist, $album, $song) {
-	global $PREAMBLE;
+	global $PREAMBLE, $JPLAYER_LIST, $JPLAYER_OGG;
+	print("<noscript>");
 	if (is_song($song) && visible($artist) && visible($album) && visible($song)) {
 		$href = $PREAMBLE . urlencode($artist) . "/" . urlencode($album) . "/" . urlencode("$song");
 		$href = $line = preg_replace("/\+/", "%20", $href);
-		$track = preg_replace("/\.[^.]*$/", "", $song);
+		$parts = pathinfo($song);
+		if ($ext == "ogg" || $ext == "OGG") {
+			$JPLAYER_OGG = "true";
+		}
 		print("<a href=\"$href\"><img src=disk.png border=0></a><a href=\"?playlist=1&artist=$artist&album=$album&song=$song\">");
-		print("<img src=music.png border=0>&nbsp;$track</a><br>");
+		print("<img src=music.png border=0>&nbsp;" . $parts["filename"] . "</a><br>");
+		$JPLAYER_LIST .= "{name:\"" . $parts["filename"] . "\"," . $parts["extension"] . ":\"$href\"},\n";
 	}
+	print("</noscript>");
 }
 
 function print_artists($search="") {
-	if ($search) {
-		$title = "Matching Artists";
-	} else {
-		$title = "All Artists";
-	}
-	print("<center><img src=group.png>&nbsp;<big><b>$title</b></big></center><ol>");
+	print("<ol>");
 	$artists = get_all_artists($search);
 	for ($i=0; $i<sizeof($artists); $i++) {
 		print_artist($artists[$i]);
@@ -430,6 +440,7 @@ function print_albums_by_search($search) {
 }
 
 function print_songs_by_album($artist, $album) {
+	global $JPLAYER_LIST, $JPLAYER_OGG;
 	print("<p align=center><img src=group.png>&nbsp;<b><big>$artist</b></big><br><img src=cd.png>&nbsp;<b>$album</b><br>\n");
 	$wiki = preg_replace("/\s*\(.*/", "", $album);
 	$wiki = urlencode($wiki);
@@ -440,6 +451,9 @@ function print_songs_by_album($artist, $album) {
 		list($artist, $album, $song) = preg_split("/\//", $songs[$i]);
 		print_song($artist, $album, $song);
 	}
+	if ($JPLAYER_LIST != "") {
+		include("jplayer.php");
+	}
 	$size = get_size_of_album($artist, $album);
         print("<p align=right>
 <a href=?playlist=1&artist=" . urlencode($artist) . "&album=" . urlencode($album) . "><img src=control_play_blue.png border=0>&nbsp;play album</a><br>
@@ -448,25 +462,33 @@ function print_songs_by_album($artist, $album) {
 }
 
 function print_misc_songs_by_artist($artist) {
+	global $JPLAYER_LIST, $JPLAYER_OGG;
 	print("<center><img src=group.png>&nbsp;<big><b>$artist</b></big><br><img src=music.png>&nbsp;<b>Miscellaneous</b></center><br>");
 	$songs = get_songs_by_album($artist);
 	for ($i=0; $i<sizeof($songs); $i++) {
 		list($artist, $album, $song) = preg_split("/\//", $songs[$i]);
 		print_song($artist, $album, $song);
 	}
+	if ($JPLAYER_LIST != "") {
+		include("jplayer.php");
+	}
 	print("<p align=right><a href=?playlist=1&artist=" . urlencode($artist) . "><img src=control_play_blue.png border=0>&nbsp;play all by artist</a></p> ");
 }
 
 function print_songs_by_search($search) {
+	global $JPLAYER_LIST, $JPLAYER_OGG;
         print("<ol>");
 	$songs = get_all_songs($search);
 	for ($i=0; $i<sizeof($songs); $i++) {
 		list($artist, $album, $song) = preg_split("/\//", $songs[$i]);
-		print_artist($artist);
-		print_album($artist, $album);
+		//print_artist($artist);
+		//print_album($artist, $album);
 		print_song($artist, $album, $song);
 
 	}
+	if ($JPLAYER_LIST != "") {
+		include("jplayer.php");
+	}
 	print("</ol>");
 }
 
@@ -480,6 +502,7 @@ function print_songs_by_search($search) {
 if (		!$artist && 
 		!$album && 
 		!$song && 
+		!$about && 
 		!$playlist && 
 		!$download_album && 
 		!$blank && 
@@ -487,7 +510,7 @@ if (		!$artist &&
 		!$middle) 
 {
 	print ("
-			<frameset rows='85,*' border=0>
+			<frameset rows='65,*' border=0>
 			<frame src=?top=1 name=_upper>
 			<frame src=?middle=1 name=_middle>
 			</frameset>
@@ -512,7 +535,7 @@ if ($blank) {
 /* Middle Frame, which includes three more frames */
 if ($middle) {
 	print ("
-			<frameset cols='33%,33%,33%' border=0>
+			<frameset cols='33%,33%,34%' border=0>
 			<frame src=?artist=_all name=_artists>
 			<frame src=?blank=1 name=_albums>
 			<frame src=?blank=1 name=_songs>
@@ -541,6 +564,9 @@ if ($top) {
     <td width=33%>
       <img src=music.png>&nbsp;<b>Songs ($songs)</b>
     </td>
+    <td width=1%>
+      <b><a href=?about=1 target=_songs title='About Musica'>?</a></b>
+    </td>
   </tr>
   <tr align=center>
     <td>
@@ -562,16 +588,27 @@ if ($top) {
         <input type=submit value=all onfocus=javascript:document.forms[0].search.value=\"\"></form>
     </td>
   </tr>
-  <tr>
-    <td colspan=3 align=center>
-      <small><small><a href=https://launchpad.net/musica target=_top>Musica</a> is <a href=http://www.gnu.org/licenses/agpl-3.0.txt target=_top>GNU AGPL 3</a> free software, Copyright &copy; 2000-2010 <a href=http://blog.dustinkirkland.com>Dustin Kirkland</a>.  <a href=http://www.famfamfam.com/lab/icons/silk/ target=_top>Icons</a> are <a href=http://creativecommons.org/licenses/by/2.5/ target=_top>CCA2.5</a>.</small></small>
-    </td>
-  </tr>
 </table></body>");
 	exit;
 }
 /*************************************************************************/
 
+/*************************************************************************/
+/* About Musica*/
+if ($about) {
+	print("
+<big><b>About Musica</b></big><br><br>
+
+<a href=https://launchpad.net/musica target=_top>Musica</a> is Free Software under the <a href=http://www.gnu.org/licenses/agpl-3.0.txt target=_top>GNU AGPL 3</a>, Copyright &copy;2000-2010 <a href=http://blog.dustinkirkland.com>Dustin Kirkland</a>.<br><br>
+
+<a href=http://www.famfamfam.com/lab/icons/silk/ target=_top>FamFamFam Silk Icons</a> are used under the <a href=http://creativecommons.org/licenses/by/3.0/ target=_top>CCA3.0</a> license.<br><br>
+
+<a href=http://www.happyworm.com/jquery/jplayer/ target=_top>jPlayer audio player plugin</a> is developed by <a href=http://www.happyworm.com/ target=_top>Happyworm</a>, and is Free, Open Source and dual licensed under the <a href=http://www.opensource.org/licenses/mit-license.php target=_top>MIT</a> and <a href=http://www.gnu.org/copyleft/gpl.html target=_top>GPL</a> licenses.<br><br>
+	");
+	exit;
+}
+/*************************************************************************/
+
 
 /*************************************************************************/
 /* Artist Frame: Display list of artists */
@@ -583,7 +620,6 @@ if ($artist == "_all") {
 /*************************************************************************/
 
 
-
 /*************************************************************************/
 /* Album Frame: Display list of albums */
 if ($artist && !$album && !$misc && !$playlist && !$download_album) {
